/*
 * Counter.java
 * Part of the B'am library - a collection of general-purpose utility classes.
 * 
 * Copyright (C)2006 Stephen Battey
 * Contact: resource@lucidviews.net
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

package net.lucidviews.util;


/**
 * A number object used for counting.
 * <br />
 * <br />
 * @author Stephen Battey
 * @version $Revision: 1.1 $
 * @since 1.1
 * @see net.lucidviews.util.VariableLong
 */
public class Counter extends VariableLong
{
	
	/*
	 * Constructors
	 */
	
	/**
	 * Create a new counter.
	 * <br />
	 * The counter is initialised with a zero value.
	 */
	public Counter()
	{
		super( 0 );
	}
	
	/**
	 * Create a new counter with a given initial value.
	 * <br />
	 * <br />
	 * @param value the initial value
	 */
	public Counter( long value )
	{
		super( value );
	}
	
	/**
	 * Create a new counter with a given initial value.
	 * <br />
	 * <br />
	 * @param value the initial value
	 * @throws NullPointerException if the initial value is <code>null</code>
	 */
	public Counter( Number value )
	{
		super( value );
	}
    
    
    /*
     * Methods
     */
    
	/**
	 * Increment the value of this counter.
	 * <br />
	 * If the number is secure an exception will be thrown.
	 * <br />
	 * <br />
	 * @throws IllegalStateException if this number is no longer in a variable
	 *                               state
	 * @see #secure
	 * @see #secure()
	 */
    public void increment()
    {
    	setValue( this.longValue() + 1 );
    }
    
	/**
	 * Decrement the value of this counter.
	 * <br />
	 * If the number is secure an exception will be thrown.
	 * <br />
	 * <br />
	 * @throws IllegalStateException if this number is no longer in a variable
	 *                               state
	 * @see #secure
	 * @see #secure()
	 */
    public void decrement()
    {
    	setValue( this.longValue() - 1 );
    }
	
}


/*
 * Change History
 *
 * $Log: Counter.java,v $
 * Revision 1.1  2006/10/15 21:20:29  Steve
 * Initial revision.
 *
 */