/*
 * VariableDoubleTest.java
 * Part of the B'am library - a collection of general-purpose utility classes.
 * 
 * Copyright (C)2006 Stephen Battey
 * Contact: resource@lucidviews.net
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

package net.lucidviews.util;

import junit.framework.TestCase;


/**
 * Test harness for the <code>VariableDouble</code> class.
 * <br />
 * <br />
 * @author Stephen Battey
 * @version $Revision: 1.2 $
 * @since 1.1
 */
public class VariableDoubleTest extends TestCase
{
	
	/*
	 * Static methods
	 */
	
	/**
	 * Runs the test in the command console.
	 * <br />
	 * @param args not used
	 */
	public static void main( String[] args )
	{
		junit.textui.TestRunner.run( VariableDoubleTest.class );
	}
	
	
	/*
	 * Test cases
	 */
	
	public void testEquals()
	{
		VariableDouble o1 = new VariableDouble( 65.348933347165026592760375 );
		VariableDouble o2 = new VariableDouble( new Double( 65.348933347165026592760375 ) );
		VariableDouble o3 = new VariableDouble( 75.348933347165026592760375 );
		
		// test objects that are equal compare as equal
		assertTrue( o1.equals( o2 ) );
		assertTrue( o2.equals( o1 ) );
		
		// test objects that are not equal don't compare as equal
		assertFalse( o1.equals( o3 ) );
		assertFalse( o3.equals( o1 ) );
		assertFalse( o2.equals( o3 ) );
		assertFalse( o3.equals( o2 ) );
	}
	
	public void testHashCode()
	{
		VariableDouble o1 = new VariableDouble( 4169.37838725395683 );
		int o1h = o1.hashCode();
		
		VariableDouble o2 = new VariableDouble( new Double( 4169.37838725395683 ) );
		int o2h = o2.hashCode();
		
		VariableDouble o3 = new VariableDouble( 7169.37838725395683 );
		int o3h = o3.hashCode();
		
		// test hashCode consistently returns the same value
		assertEquals( o1h, o1.hashCode() );
		assertEquals( o2h, o2.hashCode() );
		assertEquals( o3h, o3.hashCode() );
		
		// test hashCodes are equal for objects that are equal
		assertEquals( o1h, o2h );
	}
	
	public void testToString()
	{
		assertEquals( "4169.37838725395", new VariableDouble( 4169.37838725395 ).toString() );
		assertEquals( "4169.37838725395", new VariableDouble( new Double( 4169.37838725395 ) ).toString() );
		assertEquals( "7169.37838725395", new VariableDouble( 7169.37838725395 ).toString() );
	}
	
	public void testValues()
	{
		VariableDouble obj = new VariableDouble( 7169.37838725395683 );
		
		assertEquals( (double)7169.37838725395683, obj.doubleValue(), 0.000001 );
		assertEquals( (float)7169.37838725395683, obj.floatValue(), 0.000001 );
		assertEquals( (long)7169.37838725395683, obj.longValue() );
		assertEquals( (int)7169.37838725395683, obj.intValue() );
		assertEquals( (short)7169.37838725395683, obj.shortValue() );
		assertEquals( (byte)7169.37838725395683, obj.byteValue() );
		
		obj.setValue( (float)4723.9024957865 );
		
		assertEquals( (double)4723.9024957865f, obj.doubleValue(), 0.000001 );
		assertEquals( (float)4723.9024957865, obj.floatValue(), 0.000001 );
		assertEquals( (long)4723.9024957865, obj.longValue() );
		assertEquals( (int)4723.9024957865, obj.intValue() );
		assertEquals( (short)4723.9024957865, obj.shortValue() );
		assertEquals( (byte)4723.9024957865, obj.byteValue() );
	}
	
	public void secureValue()
	{
		VariableDouble obj = new VariableDouble( 7169.37838725395683 );
		obj.secure();
		
		try
		{
			obj.setValue( 65.34738945 );
			fail( "Value has been changed when value was secured." );
		}
		catch (IllegalStateException e)
		{
			// expected behaviour
		}
		catch (Exception e)
		{
			fail( "Unexpected exception: " + e );
		}
	}
	
}


/*
 * Change History
 *
 * $Log: VariableDoubleTest.java,v $
 * Revision 1.2  2007/12/06 21:02:31  Steve
 * Minor changes to provide compatibility with Java 1.4.
 *
 * Revision 1.1  2006/10/15 21:20:29  Steve
 * Initial revision.
 *
 */